@@ -1,3 +1,20 @@
+#  Licensed to Elasticsearch B.V. under one or more contributor
+#  license agreements. See the NOTICE file distributed with
+#  this work for additional information regarding copyright
+#  ownership. Elasticsearch B.V. licenses this file to you under
+#  the Apache License, Version 2.0 (the "License"); you may
+#  not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
+#
+# 	http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing,
+#  software distributed under the License is distributed on an
+#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+#  KIND, either express or implied.  See the License for the
+#  specific language governing permissions and limitations
+#  under the License.
+
 from .utils import NamespacedClient, query_params, _make_path, SKIP_IN_PATH
 
 
@@ -5,7 +22,9 @@ class CcrClient(NamespacedClient):
     @query_params()
     def delete_auto_follow_pattern(self, name, params=None, headers=None):
         """
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/ccr-delete-auto-follow-pattern.html>`_
+        Deletes auto-follow patterns.
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-delete-auto-follow-pattern.html>`_
 
         :arg name: The name of the auto follow pattern.
         """
@@ -22,7 +41,9 @@ class CcrClient(NamespacedClient):
     @query_params("wait_for_active_shards")
     def follow(self, index, body, params=None, headers=None):
         """
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/ccr-put-follow.html>`_
+        Creates a new follower index configured to follow the referenced leader index.
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-put-follow.html>`_
 
         :arg index: The name of the follower index
         :arg body: The name of the leader index and other optional ccr
@@ -48,7 +69,10 @@ class CcrClient(NamespacedClient):
     @query_params()
     def follow_info(self, index, params=None, headers=None):
         """
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/ccr-get-follow-info.html>`_
+        Retrieves information about all follower indices, including parameters and
+        status for each follower index
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-get-follow-info.html>`_
 
         :arg index: A comma-separated list of index patterns; use `_all`
             to perform the operation on all indices
@@ -63,7 +87,10 @@ class CcrClient(NamespacedClient):
     @query_params()
     def follow_stats(self, index, params=None, headers=None):
         """
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/ccr-get-follow-stats.html>`_
+        Retrieves follower stats. return shard-level stats about the following tasks
+        associated with each shard for the specified indices.
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-get-follow-stats.html>`_
 
         :arg index: A comma-separated list of index patterns; use `_all`
             to perform the operation on all indices
@@ -78,7 +105,9 @@ class CcrClient(NamespacedClient):
     @query_params()
     def forget_follower(self, index, body, params=None, headers=None):
         """
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current>`_
+        Removes the follower retention leases from the leader.
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-post-forget-follower.html>`_
 
         :arg index: the name of the leader index for which specified
             follower retention leases should be removed
@@ -102,7 +131,10 @@ class CcrClient(NamespacedClient):
     @query_params()
     def get_auto_follow_pattern(self, name=None, params=None, headers=None):
         """
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/ccr-get-auto-follow-pattern.html>`_
+        Gets configured auto-follow patterns. Returns the specified auto-follow pattern
+        collection.
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-get-auto-follow-pattern.html>`_
 
         :arg name: The name of the auto follow pattern.
         """
@@ -116,7 +148,10 @@ class CcrClient(NamespacedClient):
     @query_params()
     def pause_follow(self, index, params=None, headers=None):
         """
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/ccr-post-pause-follow.html>`_
+        Pauses a follower index. The follower index will not fetch any additional
+        operations from the leader index.
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-post-pause-follow.html>`_
 
         :arg index: The name of the follower index that should pause
             following its leader index.
@@ -134,7 +169,11 @@ class CcrClient(NamespacedClient):
     @query_params()
     def put_auto_follow_pattern(self, name, body, params=None, headers=None):
         """
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/ccr-put-auto-follow-pattern.html>`_
+        Creates a new named collection of auto-follow patterns against a specified
+        remote cluster. Newly created indices on the remote cluster matching any of the
+        specified patterns will be automatically configured as follower indices.
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-put-auto-follow-pattern.html>`_
 
         :arg name: The name of the auto follow pattern.
         :arg body: The specification of the auto follow pattern
@@ -154,7 +193,9 @@ class CcrClient(NamespacedClient):
     @query_params()
     def resume_follow(self, index, body=None, params=None, headers=None):
         """
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/ccr-post-resume-follow.html>`_
+        Resumes a follower index that has been paused
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-post-resume-follow.html>`_
 
         :arg index: The name of the follow index to resume following.
         :arg body: The name of the leader index and other optional ccr
@@ -174,8 +215,9 @@ class CcrClient(NamespacedClient):
     @query_params()
     def stats(self, params=None, headers=None):
         """
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/ccr-get-stats.html>`_
+        Gets all stats related to cross-cluster replication.
 
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-get-stats.html>`_
         """
         return self.transport.perform_request(
             "GET", "/_ccr/stats", params=params, headers=headers
@@ -184,7 +226,10 @@ class CcrClient(NamespacedClient):
     @query_params()
     def unfollow(self, index, params=None, headers=None):
         """
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current>`_
+        Stops the following task associated with a follower index and removes index
+        metadata and settings associated with cross-cluster replication.
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-post-unfollow.html>`_
 
         :arg index: The name of the follower index that should be turned
             into a regular index.
@@ -202,7 +247,9 @@ class CcrClient(NamespacedClient):
     @query_params()
     def pause_auto_follow_pattern(self, name, params=None, headers=None):
         """
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/ccr-pause-auto-follow-pattern.html>`_
+        Pauses an auto-follow pattern
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-pause-auto-follow-pattern.html>`_
 
         :arg name: The name of the auto follow pattern that should pause
             discovering new indices to follow.
@@ -220,7 +267,9 @@ class CcrClient(NamespacedClient):
     @query_params()
     def resume_auto_follow_pattern(self, name, params=None, headers=None):
         """
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/ccr-resume-auto-follow-pattern.html>`_
+        Resumes an auto-follow pattern that has been paused
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/ccr-resume-auto-follow-pattern.html>`_
 
         :arg name: The name of the auto follow pattern to resume
             discovering new indices to follow.
