@@ -1,3 +1,20 @@
+#  Licensed to Elasticsearch B.V. under one or more contributor
+#  license agreements. See the NOTICE file distributed with
+#  this work for additional information regarding copyright
+#  ownership. Elasticsearch B.V. licenses this file to you under
+#  the Apache License, Version 2.0 (the "License"); you may
+#  not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
+#
+# 	http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing,
+#  software distributed under the License is distributed on an
+#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+#  KIND, either express or implied.  See the License for the
+#  specific language governing permissions and limitations
+#  under the License.
+
 from .utils import NamespacedClient, query_params, _make_path, SKIP_IN_PATH
 
 
@@ -6,7 +23,8 @@ class SlmClient(NamespacedClient):
     def delete_lifecycle(self, policy_id, params=None, headers=None):
         """
         Deletes an existing snapshot lifecycle policy.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/slm-api-delete-policy.html>`_
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/slm-api-delete-policy.html>`_
 
         :arg policy_id: The id of the snapshot lifecycle policy to
             remove
@@ -26,7 +44,8 @@ class SlmClient(NamespacedClient):
         """
         Immediately creates a snapshot according to the lifecycle policy, without
         waiting for the scheduled time.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/slm-api-execute-lifecycle.html>`_
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/slm-api-execute-lifecycle.html>`_
 
         :arg policy_id: The id of the snapshot lifecycle policy to be
             executed
@@ -46,7 +65,8 @@ class SlmClient(NamespacedClient):
         """
         Deletes any snapshots that are expired according to the policy's retention
         rules.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/slm-api-execute-retention.html>`_
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/slm-api-execute-retention.html>`_
         """
         return self.transport.perform_request(
             "POST", "/_slm/_execute_retention", params=params, headers=headers
@@ -57,7 +77,8 @@ class SlmClient(NamespacedClient):
         """
         Retrieves one or more snapshot lifecycle policy definitions and information
         about the latest snapshot attempts.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/slm-api-get-policy.html>`_
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/slm-api-get-policy.html>`_
 
         :arg policy_id: Comma-separated list of snapshot lifecycle
             policies to retrieve
@@ -74,7 +95,8 @@ class SlmClient(NamespacedClient):
         """
         Returns global and policy-level statistics about actions taken by snapshot
         lifecycle management.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/slm-api-get-stats.html>`_
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/slm-api-get-stats.html>`_
         """
         return self.transport.perform_request(
             "GET", "/_slm/stats", params=params, headers=headers
@@ -84,7 +106,8 @@ class SlmClient(NamespacedClient):
     def put_lifecycle(self, policy_id, body=None, params=None, headers=None):
         """
         Creates or updates a snapshot lifecycle policy.
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/slm-api-put-policy.html>`_
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/slm-api-put-policy.html>`_
 
         :arg policy_id: The id of the snapshot lifecycle policy
         :arg body: The snapshot lifecycle policy definition to register
@@ -104,7 +127,8 @@ class SlmClient(NamespacedClient):
     def get_status(self, params=None, headers=None):
         """
         Retrieves the status of snapshot lifecycle management (SLM).
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/slm-api-get-status.html>`_
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/slm-api-get-status.html>`_
         """
         return self.transport.perform_request(
             "GET", "/_slm/status", params=params, headers=headers
@@ -114,7 +138,8 @@ class SlmClient(NamespacedClient):
     def start(self, params=None, headers=None):
         """
         Turns on snapshot lifecycle management (SLM).
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/slm-api-start.html>`_
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/slm-api-start.html>`_
         """
         return self.transport.perform_request(
             "POST", "/_slm/start", params=params, headers=headers
@@ -124,7 +149,8 @@ class SlmClient(NamespacedClient):
     def stop(self, params=None, headers=None):
         """
         Turns off snapshot lifecycle management (SLM).
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/slm-api-stop.html>`_
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/slm-api-stop.html>`_
         """
         return self.transport.perform_request(
             "POST", "/_slm/stop", params=params, headers=headers
