@@ -1,9 +1,35 @@
+#  Licensed to Elasticsearch B.V. under one or more contributor
+#  license agreements. See the NOTICE file distributed with
+#  this work for additional information regarding copyright
+#  ownership. Elasticsearch B.V. licenses this file to you under
+#  the Apache License, Version 2.0 (the "License"); you may
+#  not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
+#
+# 	http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing,
+#  software distributed under the License is distributed on an
+#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+#  KIND, either express or implied.  See the License for the
+#  specific language governing permissions and limitations
+#  under the License.
+
+# type: ignore
+
 import time
 import os
 from unittest import TestCase, SkipTest
 
-from elasticsearch7 import Elasticsearch
-from elasticsearch7.exceptions import ConnectionError
+from elasticsearch import Elasticsearch
+from elasticsearch.exceptions import ConnectionError
+
+if "ELASTICSEARCH_URL" in os.environ:
+    ELASTICSEARCH_URL = os.environ["ELASTICSEARCH_URL"]
+elif os.environ.get("TEST_SUITE") == "platinum":
+    ELASTICSEARCH_URL = "https://elastic:changeme@localhost:9200"
+else:
+    ELASTICSEARCH_URL = "http://localhost:9200"
 
 
 def get_test_client(nowait=False, **kwargs):
@@ -11,14 +37,14 @@ def get_test_client(nowait=False, **kwargs):
     kw = {"timeout": 30, "ca_certs": ".ci/certs/ca.pem"}
 
     if "PYTHON_CONNECTION_CLASS" in os.environ:
-        from elasticsearch7 import connection
+        from elasticsearch import connection
 
         kw["connection_class"] = getattr(
             connection, os.environ["PYTHON_CONNECTION_CLASS"]
         )
 
     kw.update(kwargs)
-    client = Elasticsearch([os.environ.get("ELASTICSEARCH_HOST", {})], **kw)
+    client = Elasticsearch(ELASTICSEARCH_URL, **kw)
 
     # wait for yellow status
     for _ in range(1 if nowait else 100):
@@ -45,16 +71,13 @@ class ElasticsearchTestCase(TestCase):
         return get_test_client()
 
     @classmethod
-    def setUpClass(cls):
-        super(ElasticsearchTestCase, cls).setUpClass()
+    def setup_class(cls):
         cls.client = cls._get_client()
 
-    def tearDown(self):
-        super(ElasticsearchTestCase, self).tearDown()
-
+    def teardown_method(self, _):
         # Hidden indices expanded in wildcards in ES 7.7
         expand_wildcards = ["open", "closed"]
-        if self.es_version >= (7, 7):
+        if self.es_version() >= (7, 7):
             expand_wildcards.append("hidden")
 
         self.client.indices.delete(
@@ -62,7 +85,6 @@ class ElasticsearchTestCase(TestCase):
         )
         self.client.indices.delete_template(name="*", ignore=404)
 
-    @property
     def es_version(self):
         if not hasattr(self, "_es_version"):
             version_string = self.client.info()["version"]["number"]
