@@ -1,8 +1,27 @@
+#  Licensed to Elasticsearch B.V. under one or more contributor
+#  license agreements. See the NOTICE file distributed with
+#  this work for additional information regarding copyright
+#  ownership. Elasticsearch B.V. licenses this file to you under
+#  the Apache License, Version 2.0 (the "License"); you may
+#  not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
+#
+# 	http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing,
+#  software distributed under the License is distributed on an
+#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+#  KIND, either express or implied.  See the License for the
+#  specific language governing permissions and limitations
+#  under the License.
+
 import time
+from platform import python_version
 from itertools import chain
 
+from ._version import __versionstr__
 from .connection import Urllib3HttpConnection
-from .connection_pool import ConnectionPool, DummyConnectionPool
+from .connection_pool import ConnectionPool, DummyConnectionPool, EmptyConnectionPool
 from .serializer import JSONSerializer, Deserializer, DEFAULT_SERIALIZERS
 from .exceptions import (
     ConnectionError,
@@ -10,6 +29,7 @@ from .exceptions import (
     SerializationError,
     ConnectionTimeout,
 )
+from .utils import _client_meta_version
 
 
 def get_host_info(node_info, host):
@@ -19,7 +39,7 @@ def get_host_info(node_info, host):
     `None` is returned this node will be skipped.
 
     Useful for filtering nodes (by proximity for example) or if additional
-    information needs to be provided for the :class:`~elasticsearch7.Connection`
+    information needs to be provided for the :class:`~elasticsearch.Connection`
     class. By default master only nodes are filtered out since they shouldn't
     typically be used for API operations.
 
@@ -40,10 +60,12 @@ class Transport(object):
     Main interface is the `perform_request` method.
     """
 
+    DEFAULT_CONNECTION_CLASS = Urllib3HttpConnection
+
     def __init__(
         self,
         hosts,
-        connection_class=Urllib3HttpConnection,
+        connection_class=None,
         connection_pool_class=ConnectionPool,
         host_info_callback=get_host_info,
         sniff_on_start=False,
@@ -57,13 +79,14 @@ class Transport(object):
         retry_on_status=(502, 503, 504),
         retry_on_timeout=False,
         send_get_body_as="GET",
+        meta_header=True,
         **kwargs
     ):
         """
         :arg hosts: list of dictionaries, each containing keyword arguments to
             create a `connection_class` instance
-        :arg connection_class: subclass of :class:`~elasticsearch7.Connection` to use
-        :arg connection_pool_class: subclass of :class:`~elasticsearch7.ConnectionPool` to use
+        :arg connection_class: subclass of :class:`~elasticsearch.Connection` to use
+        :arg connection_pool_class: subclass of :class:`~elasticsearch.ConnectionPool` to use
         :arg host_info_callback: callback responsible for taking the node information from
             `/_cluster/nodes`, along with already extracted information, and
             producing a list of arguments (same as `hosts` parameter)
@@ -91,11 +114,17 @@ class Transport(object):
             don't support passing bodies with GET requests. If you set this to
             'POST' a POST method will be used instead, if to 'source' then the body
             will be serialized and passed as a query parameter `source`.
+        :arg meta_header: If True will send the 'X-Elastic-Client-Meta' HTTP header containing
+            simple client metadata. Setting to False will disable the header. Defaults to True.
 
         Any extra keyword arguments will be passed to the `connection_class`
         when creating and instance unless overridden by that connection's
         options provided as part of the hosts parameter.
         """
+        if connection_class is None:
+            connection_class = self.DEFAULT_CONNECTION_CLASS
+        if not isinstance(meta_header, bool):
+            raise TypeError("meta_header must be of type bool")
 
         # serialization config
         _serializers = DEFAULT_SERIALIZERS.copy()
@@ -111,6 +140,7 @@ class Transport(object):
         self.retry_on_timeout = retry_on_timeout
         self.retry_on_status = retry_on_status
         self.send_get_body_as = send_get_body_as
+        self.meta_header = meta_header
 
         # data serializer
         self.serializer = serializer
@@ -123,10 +153,18 @@ class Transport(object):
         self.kwargs = kwargs
         self.hosts = hosts
 
-        # ...and instantiate them
-        self.set_connections(hosts)
-        # retain the original connection instances for sniffing
-        self.seed_connections = self.connection_pool.connections[:]
+        # Start with an empty pool specifically for `AsyncTransport`.
+        # It should never be used, will be replaced on first call to
+        # .set_connections()
+        self.connection_pool = EmptyConnectionPool()
+
+        if hosts:
+            # ...and instantiate them
+            self.set_connections(hosts)
+            # retain the original connection instances for sniffing
+            self.seed_connections = list(self.connection_pool.connections[:])
+        else:
+            self.seed_connections = []
 
         # Don't enable sniffing on Cloud instances.
         if kwargs.get("cloud_id", False):
@@ -135,6 +173,7 @@ class Transport(object):
 
         # sniffing data
         self.sniffer_timeout = sniffer_timeout
+        self.sniff_on_start = sniff_on_start
         self.sniff_on_connection_fail = sniff_on_connection_fail
         self.last_sniff = time.time()
         self.sniff_timeout = sniff_timeout
@@ -145,9 +184,23 @@ class Transport(object):
         if sniff_on_start:
             self.sniff_hosts(True)
 
+        # Create the default metadata for the x-elastic-client-meta
+        # HTTP header. Only requires adding the (service, service_version)
+        # tuple to the beginning of the client_meta
+        self._client_meta = (
+            ("es", _client_meta_version(__versionstr__)),
+            ("py", _client_meta_version(python_version())),
+            ("t", _client_meta_version(__versionstr__)),
+        )
+
+        # Grab the 'HTTP_CLIENT_META' property from the connection class
+        http_client_meta = getattr(connection_class, "HTTP_CLIENT_META", None)
+        if http_client_meta:
+            self._client_meta += (http_client_meta,)
+
     def add_connection(self, host):
         """
-        Create a new :class:`~elasticsearch7.Connection` instance and add it to the pool.
+        Create a new :class:`~elasticsearch.Connection` instance and add it to the pool.
 
         :arg host: kwargs that will be used to create the instance
         """
@@ -158,7 +211,7 @@ class Transport(object):
         """
         Instantiate all the connections and create new connection pool to hold them.
         Tries to identify unchanged hosts and re-use existing
-        :class:`~elasticsearch7.Connection` instances.
+        :class:`~elasticsearch.Connection` instances.
 
         :arg hosts: same as `__init__`
         """
@@ -190,8 +243,8 @@ class Transport(object):
 
     def get_connection(self):
         """
-        Retrieve a :class:`~elasticsearch7.Connection` instance from the
-        :class:`~elasticsearch7.ConnectionPool` instance.
+        Retrieve a :class:`~elasticsearch.Connection` instance from the
+        :class:`~elasticsearch.ConnectionPool` instance.
         """
         if self.sniffer_timeout:
             if time.time() >= self.last_sniff + self.sniffer_timeout:
@@ -289,7 +342,7 @@ class Transport(object):
         Mark a connection as dead (failed) in the connection pool. If sniffing
         on failure is enabled this will initiate the sniffing process.
 
-        :arg connection: instance of :class:`~elasticsearch7.Connection` that failed
+        :arg connection: instance of :class:`~elasticsearch.Connection` that failed
         """
         # mark as dead even when sniffing to avoid hitting this host during the sniff process
         self.connection_pool.mark_dead(connection)
@@ -311,12 +364,77 @@ class Transport(object):
         :arg method: HTTP method to use
         :arg url: absolute url (without host) to target
         :arg headers: dictionary of headers, will be handed over to the
-            underlying :class:`~elasticsearch7.Connection` class
+            underlying :class:`~elasticsearch.Connection` class
         :arg params: dictionary of query parameters, will be handed over to the
-            underlying :class:`~elasticsearch7.Connection` class for serialization
+            underlying :class:`~elasticsearch.Connection` class for serialization
         :arg body: body of the request, will be serialized using serializer and
             passed to the connection
         """
+        method, headers, params, body, ignore, timeout = self._resolve_request_args(
+            method, headers, params, body
+        )
+
+        for attempt in range(self.max_retries + 1):
+            connection = self.get_connection()
+
+            try:
+                status, headers_response, data = connection.perform_request(
+                    method,
+                    url,
+                    params,
+                    body,
+                    headers=headers,
+                    ignore=ignore,
+                    timeout=timeout,
+                )
+
+            except TransportError as e:
+                if method == "HEAD" and e.status_code == 404:
+                    return False
+
+                retry = False
+                if isinstance(e, ConnectionTimeout):
+                    retry = self.retry_on_timeout
+                elif isinstance(e, ConnectionError):
+                    retry = True
+                elif e.status_code in self.retry_on_status:
+                    retry = True
+
+                if retry:
+                    try:
+                        # only mark as dead if we are retrying
+                        self.mark_dead(connection)
+                    except TransportError:
+                        # If sniffing on failure, it could fail too. Catch the
+                        # exception not to interrupt the retries.
+                        pass
+                    # raise exception on last retry
+                    if attempt == self.max_retries:
+                        raise e
+                else:
+                    raise e
+
+            else:
+                # connection didn't fail, confirm it's live status
+                self.connection_pool.mark_live(connection)
+
+                if method == "HEAD":
+                    return 200 <= status < 300
+
+                if data:
+                    data = self.deserializer.loads(
+                        data, headers_response.get("content-type")
+                    )
+                return data
+
+    def close(self):
+        """
+        Explicitly closes connections
+        """
+        self.connection_pool.close()
+
+    def _resolve_request_args(self, method, headers, params, body):
+        """Resolves parameters for .perform_request()"""
         if body is not None:
             body = self.serializer.dumps(body)
 
@@ -347,57 +465,15 @@ class Transport(object):
             ignore = params.pop("ignore", ())
             if isinstance(ignore, int):
                 ignore = (ignore,)
+            client_meta = params.pop("__elastic_client_meta", ())
+        else:
+            client_meta = ()
 
-        for attempt in range(self.max_retries + 1):
-            connection = self.get_connection()
+        if self.meta_header:
+            headers = headers or {}
+            client_meta = self._client_meta + client_meta
+            headers["x-elastic-client-meta"] = ",".join(
+                "%s=%s" % (k, v) for k, v in client_meta
+            )
 
-            try:
-                status, headers_response, data = connection.perform_request(
-                    method,
-                    url,
-                    params,
-                    body,
-                    headers=headers,
-                    ignore=ignore,
-                    timeout=timeout,
-                )
-
-            except TransportError as e:
-                if method == "HEAD" and e.status_code == 404:
-                    return False
-
-                retry = False
-                if isinstance(e, ConnectionTimeout):
-                    retry = self.retry_on_timeout
-                elif isinstance(e, ConnectionError):
-                    retry = True
-                elif e.status_code in self.retry_on_status:
-                    retry = True
-
-                if retry:
-                    # only mark as dead if we are retrying
-                    self.mark_dead(connection)
-                    # raise exception on last retry
-                    if attempt == self.max_retries:
-                        raise
-                else:
-                    raise
-
-            else:
-                # connection didn't fail, confirm it's live status
-                self.connection_pool.mark_live(connection)
-
-                if method == "HEAD":
-                    return 200 <= status < 300
-
-                if data:
-                    data = self.deserializer.loads(
-                        data, headers_response.get("content-type")
-                    )
-                return data
-
-    def close(self):
-        """
-        Explicitly closes connections
-        """
-        self.connection_pool.close()
+        return method, headers, params, body, ignore, timeout
